bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.__init__
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGammaISO.__init__